==> centreon-web-22.10.29.tar.gz: centreon-web-22.10.29/src/Core/Security/ProviderConfiguration/Application/OpenId/Repository/WriteOpenIdConfigurationRepositoryInterface.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Security\ProviderConfiguration\Application\OpenId\Repository;

use Core\Security\ProviderConfiguration\Domain\OpenId\Model\AuthorizationRule;
use Core\Security\ProviderConfiguration\Domain\Model\Configuration;

interface WriteOpenIdConfigurationRepositoryInterface
{
    /**
     * Update the OpenId Provider.
     *
     * @param Configuration $configuration
     * @throws \Throwable
     */
    public function updateConfiguration(Configuration $configuration): void;

    /**
     * Delete Authorization rules
     * @throws \Throwable
     */
    public function deleteAuthorizationRules(): void;

    /**
     * Insert Authorization rules
     *
     * @param AuthorizationRule[] $authorizationRules
     * @throws \Throwable
     */
    public function insertAuthorizationRules(array $authorizationRules): void;
}

==> centreon-web-23.04.29.tar.gz: centreon-web-23.04.29/src/Core/Security/ProviderConfiguration/Application/OpenId/Repository/WriteOpenIdConfigurationRepositoryInterface.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Security\ProviderConfiguration\Application\OpenId\Repository;

use Core\Security\ProviderConfiguration\Domain\Model\AuthorizationRule;
use Core\Security\ProviderConfiguration\Domain\Model\Configuration;

interface WriteOpenIdConfigurationRepositoryInterface
{
    /**
     * Update the OpenId Provider.
     *
     * @param Configuration $configuration
     * @throws \Throwable
     */
    public function updateConfiguration(Configuration $configuration): void;

    /**
     * Delete Authorization rules
     * @throws \Throwable
     */
    public function deleteAuthorizationRules(): void;

    /**
     * Insert Authorization rules
     *
     * @param AuthorizationRule[] $authorizationRules
     * @throws \Throwable
     */
    public function insertAuthorizationRules(array $authorizationRules): void;
}
